import { Subject } from 'rxjs';
import { FormsModule } from '@angular/forms';
import { CommonModule } from '@angular/common';
import { Injectable, NgModule, Component, Input, EventEmitter, Output, ComponentFactoryResolver, ViewChild, ViewContainerRef, ViewEncapsulation, defineInjectable } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/angular-tree-grid.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AngularTreeGridService {
    constructor() {
        this.display_data_observable = new Subject();
        this.display_data_observable$ = this.display_data_observable.asObservable();
    }
    /**
     * @param {?} display_data
     * @return {?}
     */
    updateDisplayDataObservable(display_data) {
        this.display_data_observable.next(display_data);
    }
    /**
     * @param {?} display_data
     * @param {?} configs
     * @param {?} row_id
     * @return {?}
     */
    findRowIndex(display_data, configs, row_id) {
        return display_data.map((/**
         * @param {?} row
         * @return {?}
         */
        row => row[configs.id_field])).
            indexOf(row_id);
    }
    /**
     * @param {?} display_data
     * @return {?}
     */
    selectAll(display_data) {
        display_data.forEach((/**
         * @param {?} data
         * @return {?}
         */
        data => {
            data.row_selected = true;
        }));
    }
    /**
     * @param {?} display_data
     * @return {?}
     */
    deSelectAll(display_data) {
        display_data.forEach((/**
         * @param {?} data
         * @return {?}
         */
        data => {
            data.row_selected = false;
        }));
    }
    /**
     * @param {?} expand_tracker
     * @return {?}
     */
    expandAll(expand_tracker) {
        for (const key in expand_tracker) {
            if (expand_tracker.hasOwnProperty(key)) {
                expand_tracker[key] = true;
            }
        }
    }
    /**
     * @param {?} expand_tracker
     * @return {?}
     */
    collapseAll(expand_tracker) {
        for (const key in expand_tracker) {
            if (expand_tracker.hasOwnProperty(key)) {
                expand_tracker[key] = false;
            }
        }
        expand_tracker[''] = true;
    }
    /**
     * @param {?} row_id
     * @param {?} expand_tracker
     * @param {?} expand_event
     * @param {?} suppress_event
     * @param {?} configs
     * @param {?} display_data
     * @param {?} store
     * @return {?}
     */
    expandRow(row_id, expand_tracker, expand_event, suppress_event, configs, display_data, store) {
        if (configs.subgrid) {
            this.expandSubgridRow(row_id, expand_tracker, expand_event, suppress_event, configs, display_data, store);
            return;
        }
        /** @type {?} */
        const row_index = this.findRowIndex(display_data, configs, row_id);
        /** @type {?} */
        const row_data = display_data[row_index];
        /** @type {?} */
        const pathx = row_data.pathx;
        /** @type {?} */
        const parts = pathx.split('.');
        expand_tracker[row_data.pathx] = true;
        /** @type {?} */
        let expanded_count = 1;
        for (let index = 0; index < display_data.length; index++) {
            /** @type {?} */
            const record = display_data[index];
            // Stop when all rows are expanded.
            if (expanded_count >= parts.length) {
                return;
            }
            // Join paths as we expand.
            /** @type {?} */
            const key = parts.slice(0, expanded_count).join('.');
            // We don't want to expand it's children here.
            if (record.pathx.indexOf(key) !== -1) {
                expanded_count += 1;
                expand_tracker[record.pathx] = true;
                if (!suppress_event) {
                    if (configs.load_children_on_expand) {
                        this.emitExpandRowEvent(expand_tracker, expand_event, store, row_data, configs);
                    }
                    else {
                        expand_event.emit({ event: null, data: row_data });
                    }
                }
            }
        }
    }
    /**
     * @param {?} row_id
     * @param {?} expand_tracker
     * @param {?} collapse_event
     * @param {?} suppress_event
     * @param {?} configs
     * @param {?} display_data
     * @return {?}
     */
    collapseRow(row_id, expand_tracker, collapse_event, suppress_event, configs, display_data) {
        /** @type {?} */
        const row_index = this.findRowIndex(display_data, configs, row_id);
        /** @type {?} */
        const row_data = display_data[row_index];
        /** @type {?} */
        const pathx = row_data.pathx;
        expand_tracker[pathx] = false;
        // Collapse children rows as well
        display_data.forEach((/**
         * @param {?} record
         * @return {?}
         */
        record => {
            if (record.pathx.indexOf(pathx) !== -1) {
                expand_tracker[record.pathx] = 0;
                if (!suppress_event) {
                    collapse_event.emit({ event: null, data: row_data });
                }
            }
        }));
    }
    /**
     * @param {?} expand_tracker
     * @param {?} expand
     * @param {?} store
     * @param {?} row_data
     * @param {?} configs
     * @return {?}
     */
    emitExpandRowEvent(expand_tracker, expand, store, row_data, configs) {
        /** @type {?} */
        const promise = new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            expand.emit({
                data: row_data,
                resolve: resolve
            });
        }));
        expand_tracker[row_data.pathx] = true;
        store.remove_children(row_data);
        row_data.is_loading = true;
        // Add Child rows to the table.
        promise.then((/**
         * @param {?} child_rows
         * @return {?}
         */
        (child_rows) => {
            row_data.is_loading = false;
            store.remove_children(row_data);
            if (child_rows) {
                child_rows.map((/**
                 * @param {?} child
                 * @return {?}
                 */
                child => {
                    child.leaf = true;
                    child.levelx = row_data.levelx + 1;
                    child.pathx = row_data.pathx + '.' + child[configs.id_field];
                    child.parent_pathx = row_data.pathx;
                    child[configs.parent_id_field] = row_data[configs.id_field];
                }));
                store.add_children(row_data, child_rows);
            }
        })).catch((/**
         * @param {?} err
         * @return {?}
         */
        (err) => { }));
    }
    /**
     * @param {?} display_data
     * @param {?} configs
     * @param {?} row_id
     * @return {?}
     */
    disableRowSelection(display_data, configs, row_id) {
        /** @type {?} */
        const row_index = this.findRowIndex(display_data, configs, row_id);
        display_data[row_index].selection_disabled = true;
    }
    /**
     * @param {?} display_data
     * @param {?} configs
     * @param {?} row_id
     * @return {?}
     */
    enableRowSelection(display_data, configs, row_id) {
        /** @type {?} */
        const row_index = this.findRowIndex(display_data, configs, row_id);
        display_data[row_index].selection_disabled = false;
    }
    /**
     * @param {?} display_data
     * @param {?} configs
     * @param {?} row_id
     * @return {?}
     */
    disableRowExpand(display_data, configs, row_id) {
        /** @type {?} */
        const row_index = this.findRowIndex(display_data, configs, row_id);
        display_data[row_index].expand_disabled = true;
    }
    /**
     * @param {?} display_data
     * @param {?} configs
     * @param {?} row_id
     * @return {?}
     */
    enableRowExpand(display_data, configs, row_id) {
        /** @type {?} */
        const row_index = this.findRowIndex(display_data, configs, row_id);
        display_data[row_index].expand_disabled = false;
    }
    /**
     * @param {?} row_id
     * @param {?} expand_tracker
     * @param {?} expand_event
     * @param {?} suppress_event
     * @param {?} configs
     * @param {?} display_data
     * @param {?} store
     * @return {?}
     */
    expandSubgridRow(row_id, expand_tracker, expand_event, suppress_event, configs, display_data, store) {
        /** @type {?} */
        const row_index = this.findRowIndex(display_data, configs, row_id);
        /** @type {?} */
        const row_data = display_data[row_index];
        expand_tracker[row_data.pathx] = true;
        if (!suppress_event) {
            this.emitSubgridExpandRowEvent(expand_tracker, expand_event, store, row_data);
        }
    }
    /**
     * @param {?} expand_tracker
     * @param {?} expand
     * @param {?} store
     * @param {?} row_data
     * @return {?}
     */
    emitSubgridExpandRowEvent(expand_tracker, expand, store, row_data) {
        /** @type {?} */
        const promise = new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            expand.emit({
                data: row_data,
                resolve: resolve
            });
        }));
        expand_tracker[row_data.pathx] = true;
        /** @type {?} */
        const blank_row = store.showBlankRow(row_data);
        blank_row.loading_children = true;
        // Add Child rows to the table.
        promise.then((/**
         * @param {?} child_rows
         * @return {?}
         */
        (child_rows) => {
            blank_row.loading_children = false;
            if (child_rows) {
                child_rows.map((/**
                 * @param {?} child
                 * @return {?}
                 */
                child => {
                    child.leaf = true;
                }));
                blank_row.children = child_rows;
            }
            else {
                // Persist old children. If didn't exist then assign blank array.
                if (!blank_row.children) {
                    blank_row.children = [];
                }
            }
        })).catch((/**
         * @param {?} err
         * @return {?}
         */
        (err) => { }));
    }
}
AngularTreeGridService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
/** @nocollapse */
AngularTreeGridService.ctorParameters = () => [];
/** @nocollapse */ AngularTreeGridService.ngInjectableDef = defineInjectable({ factory: function AngularTreeGridService_Factory() { return new AngularTreeGridService(); }, token: AngularTreeGridService, providedIn: "root" });

/**
 * @fileoverview added by tsickle
 * Generated from: lib/store/store.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class Store {
    /**
     * @param {?} angularTreeGridService
     */
    constructor(angularTreeGridService) {
        this.angularTreeGridService = angularTreeGridService;
    }
    /**
     * @return {?}
     */
    getRawData() {
        return this.raw_data;
    }
    /**
     * @param {?} raw_data
     * @return {?}
     */
    setRawData(raw_data) {
        this.raw_data = raw_data;
    }
    /**
     * @return {?}
     */
    getProcessedData() {
        return this.processed_data;
    }
    /**
     * @param {?} processed_data
     * @return {?}
     */
    setProcessedData(processed_data) {
        this.processed_data = processed_data;
        this.setDisplayData([...processed_data]);
    }
    /**
     * @return {?}
     */
    getDisplayData() {
        return this.display_data;
    }
    /**
     * @param {?} display_data
     * @return {?}
     */
    setDisplayData(display_data) {
        this.display_data = display_data;
        this.angularTreeGridService.updateDisplayDataObservable(this.display_data);
    }
    /**
     * Show Blank row for subgrid.
     *
     * @param {?} row_data Row Data
     * @return {?} blank_row
     */
    showBlankRow(row_data) {
        /** @type {?} */
        const row_index = this.display_data.map((/**
         * @param {?} row
         * @return {?}
         */
        row => row[this.configs.id_field])).
            indexOf(row_data[this.configs.id_field]);
        /** @type {?} */
        let blank_row = this.display_data[row_index + 1];
        if (!blank_row || blank_row.parent_pathx !== row_data[this.configs.id_field]) {
            blank_row = {
                leaf: true,
                row_selected: true,
                // By default make it selected as it's never going to be selected manually.
                parent_pathx: row_data[this.configs.id_field]
            };
            blank_row[this.configs.id_field] = -1;
            this.display_data.splice(row_index + 1, 0, blank_row);
        }
        return blank_row;
    }
    /**
     * @param {?} row_data
     * @return {?}
     */
    remove_children(row_data) {
        /** @type {?} */
        const new_processed_data = [];
        for (let index = 0; index < this.processed_data.length; index++) {
            /** @type {?} */
            const element = this.processed_data[index];
            if (element[this.configs.parent_id_field] !== row_data[this.configs.id_field]) {
                new_processed_data.push(element);
            }
        }
        this.setProcessedData(new_processed_data);
    }
    /**
     * @param {?} row_data
     * @param {?} children
     * @return {?}
     */
    add_children(row_data, children) {
        /** @type {?} */
        const row_index = this.processed_data.map((/**
         * @param {?} row
         * @return {?}
         */
        row => row[this.configs.id_field])).
            indexOf(row_data[this.configs.id_field]);
        /** @type {?} */
        const top_rows = this.processed_data.slice(0, row_index + 1);
        /** @type {?} */
        const bottom_rows = this.processed_data.slice(row_index + 1);
        this.processed_data = top_rows.concat(children).concat(bottom_rows);
        this.setDisplayData([...this.processed_data]);
        this.angularTreeGridService.updateDisplayDataObservable(this.display_data);
    }
    /**
     * @param {?} columns
     * @param {?} search_values
     * @return {?}
     */
    filterBy(columns, search_values) {
        this.display_data = this.processed_data.filter((/**
         * @param {?} record
         * @return {?}
         */
        (record) => {
            /** @type {?} */
            let found = true;
            for (let index = 0; index < columns.length; index++) {
                /** @type {?} */
                const column = columns[index];
                /** @type {?} */
                let column_value = record[column.name];
                /** @type {?} */
                let search_value = search_values[index];
                // If blank then continue.
                if (!search_value) {
                    continue;
                }
                // Call custom filter function.
                if (column.filter_function) {
                    /** @type {?} */
                    const response = column.filter_function(record, column, column_value, search_value);
                    if (response === false) {
                        found = false;
                    }
                }
                else {
                    if (typeof (column_value) === 'number') {
                        if (column_value !== parseInt(search_value, 10)) {
                            found = false;
                        }
                    }
                    else {
                        if (!column.case_sensitive_filter) {
                            column_value = column_value.toLowerCase();
                            search_value = search_value.toLowerCase();
                        }
                        if (column_value.indexOf(search_value) === -1) {
                            found = false;
                        }
                    }
                }
            }
            return found;
        }));
        this.angularTreeGridService.updateDisplayDataObservable(this.display_data);
    }
    /**
     * @param {?} data
     * @param {?} configs
     * @return {?}
     */
    findTopParentNode(data, configs) {
        /** @type {?} */
        const ids = data.map((/**
         * @param {?} element
         * @return {?}
         */
        element => element[configs.id_field]));
        /** @type {?} */
        let top_parents = [];
        // Find parents ie if parent_id is not present in ids.
        data.forEach((/**
         * @param {?} element
         * @return {?}
         */
        element => {
            if (ids.indexOf(element[configs.parent_id_field]) === -1) {
                top_parents.push(element[configs.parent_id_field]);
            }
        }));
        // Remove duplicates
        top_parents = top_parents.filter((/**
         * @param {?} item
         * @param {?} pos
         * @param {?} self
         * @return {?}
         */
        function (item, pos, self) {
            return self.indexOf(item) === pos;
        }));
        return top_parents;
    }
    /**
     * @param {?} data
     * @param {?} expand_tracker
     * @param {?} configs
     * @param {?} edit_tracker
     * @param {?} internal_configs
     * @return {?}
     */
    processData(data, expand_tracker, configs, edit_tracker, internal_configs) {
        /** @type {?} */
        const top_parents = this.findTopParentNode(data, configs);
        /** @type {?} */
        const processed_data = [];
        internal_configs.top_parents = top_parents;
        data.map((/**
         * @param {?} rec
         * @return {?}
         */
        rec => {
            rec.pathx = [];
            rec.leaf = false;
        }));
        top_parents.forEach((/**
         * @param {?} top_parent
         * @return {?}
         */
        top_parent => {
            /** @type {?} */
            const children = this.findChildren(data, top_parent, configs);
            this.orderData(data, processed_data, configs, children, [], 0);
        }));
        processed_data.map((/**
         * @param {?} rec
         * @return {?}
         */
        rec => {
            /** @type {?} */
            const parent_pathx = rec.parent_pathx;
            rec.parent_pathx = parent_pathx.join('.');
            parent_pathx.push(rec[configs.id_field]);
            // Add current id to create current path.
            rec.pathx = parent_pathx.join('.');
            expand_tracker[rec.pathx] = false;
            edit_tracker[rec[configs.id_field]] = false;
            // For Subgrid feature, expect all rows are expandable.
            if (configs.subgrid) {
                rec.leaf = false;
            }
        }));
        // Expand root.
        expand_tracker[''] = true;
        this.setProcessedData(processed_data);
        this.setRawData(data);
        this.configs = configs;
    }
    /**
     * @param {?} data
     * @param {?} id
     * @param {?} configs
     * @return {?}
     */
    findChildren(data, id, configs) {
        return data.filter((/**
         * @param {?} rec
         * @return {?}
         */
        rec => rec[configs.parent_id_field] === id));
    }
    /**
     * @param {?} data
     * @param {?} processed_data
     * @param {?} configs
     * @param {?} parents
     * @param {?} paths
     * @param {?} levelx
     * @return {?}
     */
    orderData(data, processed_data, configs, parents, paths, levelx) {
        parents.forEach((/**
         * @param {?} parent
         * @return {?}
         */
        parent => {
            /** @type {?} */
            const children = this.findChildren(data, parent[configs.id_field], configs);
            if (children.length === 0) {
                parent.leaf = true;
                parent.levelx = levelx;
                parent.parent_pathx = [...paths];
                processed_data.push(parent);
            }
            else {
                parent.parent_pathx = [...paths];
                parent.levelx = levelx;
                processed_data.push(parent);
                /** @type {?} */
                const newPaths = [...paths, parent[configs.id_field]];
                this.orderData(data, processed_data, configs, children, newPaths, levelx + 1);
            }
        }));
    }
    /**
     * @return {?}
     */
    refreshDisplayData() {
        this.display_data = this.processed_data;
        this.angularTreeGridService.updateDisplayDataObservable(this.display_data);
    }
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/angular-tree-grid.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AngularTreeGridComponent {
    /**
     * @param {?} angularTreeGridService
     */
    constructor(angularTreeGridService) {
        this.angularTreeGridService = angularTreeGridService;
        this.processed_data = [];
        this.expand_tracker = {};
        this.columns = [];
        this.edit_tracker = {}; // Track Edit options.
        // Track Edit options.
        this.internal_configs = {
            show_add_row: false,
            show_parent_col: false,
            all_selected: false
        };
        this.store = new Store(this.angularTreeGridService);
        this.default_configs = {
            css: {
                expand_class: 'plus',
                collapse_class: 'minus',
                add_class: 'plus',
                edit_class: '',
                delete_class: '',
                save_class: '',
                cancel_class: '',
                row_selection_class: 'selected',
                header_class: '',
                row_filter_class: '',
                table_class: ''
            },
            actions: {
                edit: false,
                add: false,
                delete: false,
                resolve_edit: false,
                resolve_add: false,
                resolve_delete: false,
                edit_parent: false
            },
            data_loading_text: 'Loading...',
            filter: false,
            multi_select: false,
            show_parent_on_edit: true,
            show_summary_row: false,
            subgrid: false,
            load_children_on_expand: false,
            action_column_width: '60px',
            action_column_position: 'first',
            action_column_text: 'Actions',
            row_class_function: (/**
             * @return {?}
             */
            () => true),
            row_edit_function: (/**
             * @return {?}
             */
            () => true),
            row_delete_function: (/**
             * @return {?}
             */
            () => true),
            subgrid_config: {
                show_summary_row: false,
                data_loading_text: 'Loading...'
            }
        };
        this.default_column_config = {
            sorted: 0,
            sort_type: null,
            editable: false,
            hidden: false,
            filter: true,
            case_sensitive_filter: false
        };
        this.cellclick = new EventEmitter();
        this.expand = new EventEmitter();
        this.collapse = new EventEmitter();
        this.rowselect = new EventEmitter();
        this.rowdeselect = new EventEmitter();
        this.rowselectall = new EventEmitter();
        this.rowdeselectall = new EventEmitter();
        this.rowadd = new EventEmitter();
        this.rowsave = new EventEmitter();
        this.rowdelete = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (!this.validateConfigs()) {
            return;
        }
        this.setDefaultConfigs();
        this.setColumnNames();
    }
    /**
     * @return {?}
     */
    ngOnChanges() {
        if (!this.validateConfigs()) {
            return;
        }
        this.setDefaultConfigs();
        this.setColumnNames();
        this.store.processData(this.data, this.expand_tracker, this.configs, this.edit_tracker, this.internal_configs);
    }
    /**
     * @return {?}
     */
    validateConfigs() {
        if (!this.data) {
            window.console.warn('data can\'t be empty!');
            return;
        }
        if (!this.configs) {
            window.console.warn('configs can\'t be empty!');
            return;
        }
        /** @type {?} */
        const element = this.data[0];
        /** @type {?} */
        let isValidated = true;
        if (!this.configs.id_field) {
            isValidated = false;
            window.console.error('id field is mandatory!');
        }
        if (!this.configs.parent_id_field && !this.configs.subgrid) {
            isValidated = false;
            window.console.error('parent_id field is mandatory!');
        }
        if (element && !element.hasOwnProperty(this.configs.id_field)) {
            isValidated = false;
            console.error('id_field doesn\'t exist!');
        }
        if (element && !element.hasOwnProperty(this.configs.parent_id_field)
            && !this.configs.subgrid
            && !this.configs.load_children_on_expand) {
            isValidated = false;
            console.error('parent_id_field doesn\'t exist!');
        }
        if (element && !element.hasOwnProperty(this.configs.parent_display_field)) {
            isValidated = false;
            console.error('parent_display_field doesn\'t exist! Basically this field will be expanded.');
        }
        if (this.configs.subgrid && !this.configs.subgrid_config) {
            isValidated = false;
            console.error('subgrid_config doesn\'t exist!');
        }
        if (this.configs.subgrid && this.configs.subgrid_config && !this.configs.subgrid_config.id_field) {
            isValidated = false;
            console.error('id_field of subgrid doesn\'t exist!');
        }
        if (this.configs.subgrid && this.configs.subgrid_config && !this.configs.subgrid_config.columns) {
            isValidated = false;
            console.error('columns of subgrid doesn\'t exist!');
        }
        return isValidated;
    }
    /**
     * @return {?}
     */
    setDefaultConfigs() {
        this.processed_data = [];
        this.configs = Object.assign({}, this.default_configs, this.configs);
        // Deep clone.
        this.configs.actions = Object.assign({}, this.default_configs.actions, this.configs.actions);
        this.configs.css = Object.assign({}, this.default_configs.css, this.configs.css);
        this.configs.subgrid_config = Object.assign({}, this.default_configs.subgrid_config, this.configs.subgrid_config);
        if (this.configs.subgrid) {
            this.configs.actions.add = false;
        }
    }
    /**
     * @return {?}
     */
    setColumnNames() {
        this.columns = this.configs.columns ? this.configs.columns : [];
        // If columns doesn't exist in user's object.
        if (!this.configs.columns) {
            /** @type {?} */
            const column_keys = Object.keys(this.data[0]);
            // Insert Header and default configuration.
            column_keys.forEach((/**
             * @param {?} key
             * @return {?}
             */
            key => {
                this.columns.push(Object.assign({ 'header': key, 'name': key }, this.default_column_config));
            }));
        }
        else {
            // Insert Header and default configuration.
            for (let i = 0; i < this.columns.length; i++) {
                this.columns[i] = Object.assign({}, this.default_column_config, this.columns[i]);
            }
        }
    }
    /**
     * @return {?}
     */
    collapseAll() {
        this.angularTreeGridService.collapseAll(this.expand_tracker);
    }
    /**
     * @return {?}
     */
    expandAll() {
        this.angularTreeGridService.expandAll(this.expand_tracker);
    }
    /**
     * @return {?}
     */
    selectAll() {
        this.angularTreeGridService.selectAll(this.store.getDisplayData());
        this.internal_configs.all_selected = true;
    }
    /**
     * @return {?}
     */
    deSelectAll() {
        this.angularTreeGridService.deSelectAll(this.store.getDisplayData());
        this.internal_configs.all_selected = false;
    }
    /**
     * @param {?} row_id
     * @param {?=} suppress_event
     * @return {?}
     */
    expandRow(row_id, suppress_event) {
        this.angularTreeGridService.expandRow(row_id, this.expand_tracker, this.expand, suppress_event, this.configs, this.store.getDisplayData(), this.store);
    }
    /**
     * @param {?} row_id
     * @param {?=} suppress_event
     * @return {?}
     */
    collapseRow(row_id, suppress_event) {
        this.angularTreeGridService.collapseRow(row_id, this.expand_tracker, this.collapse, suppress_event, this.configs, this.store.getDisplayData());
    }
    /**
     * @param {?} row_id
     * @return {?}
     */
    disableRowSelection(row_id) {
        this.angularTreeGridService.disableRowSelection(this.store.getDisplayData(), this.configs, row_id);
    }
    /**
     * @param {?} row_id
     * @return {?}
     */
    enableRowSelection(row_id) {
        this.angularTreeGridService.enableRowSelection(this.store.getDisplayData(), this.configs, row_id);
    }
    /**
     * @param {?} row_id
     * @return {?}
     */
    disableRowExpand(row_id) {
        this.angularTreeGridService.disableRowExpand(this.store.getDisplayData(), this.configs, row_id);
    }
    /**
     * @param {?} row_id
     * @return {?}
     */
    enableRowExpand(row_id) {
        this.angularTreeGridService.enableRowExpand(this.store.getDisplayData(), this.configs, row_id);
    }
}
AngularTreeGridComponent.decorators = [
    { type: Component, args: [{
                selector: 'db-angular-tree-grid',
                template: "<table [attr.class]=\"'db-tree-view ' + configs.css.table_class\" >\r\n    <thead \r\n        db-tree-head\r\n        [store]=\"store\"\r\n        [expand_tracker]=\"expand_tracker\"\r\n        [internal_configs]=\"internal_configs\"\r\n        [edit_tracker]=\"edit_tracker\"\r\n        [rowselectall]=\"rowselectall\"\r\n        [rowdeselectall]=\"rowdeselectall\"\r\n        [columns]=\"columns\"\r\n        [configs]=\"configs\">\r\n    </thead>\r\n\r\n    <tbody \r\n        db-tree-body\r\n        [store]=\"store\"\r\n        [expand_tracker]=\"expand_tracker\"\r\n        [edit_tracker]=\"edit_tracker\"\r\n        [internal_configs]=\"internal_configs\"\r\n        [columns]=\"columns\"\r\n        [configs]=\"configs\"\r\n        [cellclick]=\"cellclick\"\r\n        [expand]=\"expand\"\r\n        [collapse]=\"collapse\"\r\n        [rowdelete]=\"rowdelete\"\r\n        [rowsave]=\"rowsave\"\r\n        [rowadd]=\"rowadd\"\r\n        [rowselect]=\"rowselect\"\r\n        [rowdeselect]=\"rowdeselect\"\r\n    >        \r\n    </tbody>\r\n</table>",
                styles: [".db-tree-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;word-break:keep-all;border:1px solid gray;color:#4b4b4b}"]
            }] }
];
/** @nocollapse */
AngularTreeGridComponent.ctorParameters = () => [
    { type: AngularTreeGridService }
];
AngularTreeGridComponent.propDecorators = {
    data: [{ type: Input }],
    configs: [{ type: Input }],
    cellclick: [{ type: Output }],
    expand: [{ type: Output }],
    collapse: [{ type: Output }],
    rowselect: [{ type: Output }],
    rowdeselect: [{ type: Output }],
    rowselectall: [{ type: Output }],
    rowdeselectall: [{ type: Output }],
    rowadd: [{ type: Output }],
    rowsave: [{ type: Output }],
    rowdelete: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-body/tree-body.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TreeBodyComponent {
    /**
     * @param {?} angularTreeGridService
     */
    constructor(angularTreeGridService) {
        this.angularTreeGridService = angularTreeGridService;
        this.parents = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.display_data = this.store.getDisplayData();
        this.angularTreeGridService.display_data_observable$.subscribe((/**
         * @param {?} store
         * @return {?}
         */
        (store) => {
            this.display_data = this.store.getDisplayData();
            this.setParents();
        }));
        this.setParents();
    }
    /**
     * @return {?}
     */
    setParents() {
        this.parents = this.store.raw_data.map((/**
         * @param {?} element
         * @return {?}
         */
        element => {
            return {
                'id': element[this.configs.id_field],
                'value': element[this.configs.parent_display_field]
            };
        }));
    }
    /**
     * @param {?} element
     * @return {?}
     */
    refreshData(element) {
        // If edit parent is not true then don't refresh.
        if (!this.configs.actions.edit_parent) {
            return;
        }
        element[this.configs.parent_id_field] = parseInt(element[this.configs.parent_id_field], 10);
        this.expand_tracker = {};
        this.edit_tracker = {};
        this.store.processData(this.store.getRawData(), this.expand_tracker, this.configs, this.edit_tracker, this.internal_configs);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onRowExpand(event) {
        /** @type {?} */
        const row_data = event.data;
        if (!this.configs.load_children_on_expand) {
            this.expand_tracker[row_data.pathx] = true;
            this.expand.emit(event);
        }
        else {
            this.angularTreeGridService.emitExpandRowEvent(this.expand_tracker, this.expand, this.store, row_data, this.configs);
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onRowCollapse(event) {
        /** @type {?} */
        const row_data = event.data;
        this.expand_tracker[row_data.pathx] = false;
        // Collapse all of its children.
        /** @type {?} */
        const keys = Object.keys(this.expand_tracker);
        keys.forEach((/**
         * @param {?} key
         * @return {?}
         */
        key => {
            if (key.indexOf(row_data.pathx) !== -1) {
                this.expand_tracker[key] = 0;
            }
        }));
        this.collapse.emit(event);
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    saveRecord($event) {
        /** @type {?} */
        const element = $event.data;
        if (this.configs.actions.resolve_edit) {
            /** @type {?} */
            const promise = new Promise((/**
             * @param {?} resolve
             * @param {?} reject
             * @return {?}
             */
            (resolve, reject) => {
                this.rowsave.emit({
                    data: element,
                    resolve: resolve
                });
            }));
            promise.then((/**
             * @return {?}
             */
            () => {
                this.checkAndRefreshData(element);
            })).catch((/**
             * @param {?} err
             * @return {?}
             */
            (err) => { }));
        }
        else {
            this.checkAndRefreshData(element);
            this.rowsave.emit(element);
        }
    }
    /**
     * @param {?} element
     * @return {?}
     */
    checkAndRefreshData(element) {
        this.edit_tracker[element[this.configs.id_field]] = false;
        this.internal_configs.show_parent_col = false;
        // Only refresh if Parent has been changed.
        if (this.internal_configs.current_edited_row[this.configs.parent_id_field]
            !== element[this.configs.parent_id_field]) {
            this.refreshData(element);
        }
    }
    /**
     * @param {?} element
     * @return {?}
     */
    addRow(element) {
        if (this.configs.actions.resolve_add) {
            /** @type {?} */
            const promise = new Promise((/**
             * @param {?} resolve
             * @param {?} reject
             * @return {?}
             */
            (resolve, reject) => {
                this.rowadd.emit({
                    data: element,
                    resolve: resolve
                });
            }));
            promise.then((/**
             * @return {?}
             */
            () => {
                this.internal_configs.show_add_row = false;
                this.refreshData(element);
            })).catch((/**
             * @param {?} err
             * @return {?}
             */
            (err) => { }));
        }
        else {
            this.refreshData(element);
            this.internal_configs.show_add_row = false;
            this.rowadd.emit(element);
        }
    }
    /**
     * @param {?} row_data
     * @return {?}
     */
    cancelEdit(row_data) {
        /** @type {?} */
        const index = row_data[this.configs.id_field];
        // Cancel all changes ie copy from back up.
        Object.assign(row_data, this.internal_configs.current_edited_row);
        this.edit_tracker[index] = false;
        this.internal_configs.show_parent_col = false;
    }
    /**
     * @param {?} row_data
     * @param {?} event
     * @return {?}
     */
    selectRow(row_data, event) {
        // Don't run if Multi select is enabled.
        if (this.configs.multi_select) {
            return;
        }
        this.store.getDisplayData().forEach((/**
         * @param {?} data
         * @return {?}
         */
        data => {
            data.row_selected = false;
        }));
        row_data.row_selected = true;
        this.rowselect.emit({ data: row_data, event: event });
    }
    /**
     * @param {?} row_data
     * @param {?} event
     * @return {?}
     */
    selectRowOnCheck(row_data, event) {
        if (event.target.checked) {
            row_data.row_selected = true;
            this.rowselect.emit({ data: row_data, event: event });
        }
        else {
            row_data.row_selected = false;
            this.rowdeselect.emit({ data: row_data, event: event });
        }
        this.setSelectAllConfig();
    }
    /**
     * Set Select All config on Select change.
     *
     * @return {?}
     */
    setSelectAllConfig() {
        /** @type {?} */
        let select_all = true;
        this.store.getDisplayData().forEach((/**
         * @param {?} data
         * @return {?}
         */
        data => {
            if (!data.row_selected) {
                select_all = false;
            }
        }));
        this.internal_configs.all_selected = select_all;
    }
}
TreeBodyComponent.decorators = [
    { type: Component, args: [{
                selector: '[db-tree-body]',
                template: "<ng-container *ngIf=\"configs\">\r\n  <tr *ngIf=\"store.raw_data.length==0\">\r\n    <td [innerHTML]=\"configs.data_loading_text\" [attr.colspan]=\"columns.length + 1\" style=\"text-align: center\"></td>\r\n  </tr>\r\n  <tr db-filter-row [columns]=\"columns\" [configs]=\"configs\" [store]=\"store\" [internal_configs]=\"internal_configs\"\r\n    *ngIf=\"configs.filter\" [expand_tracker]=\"expand_tracker\" [ngClass]=\"configs.css.row_filter_class\">\r\n  </tr>\r\n  <tr db-add-row [columns]=\"columns\" [configs]=\"configs\" [internal_configs]=\"internal_configs\" [store]=\"store\"\r\n    (rowadd)=\"addRow($event)\" *ngIf=\"internal_configs.show_add_row\" class=\"{{configs.row_class_function()}}\">\r\n  </tr>\r\n  <ng-container *ngIf=\"configs.subgrid\">\r\n    <tr db-subgrid *ngFor=\"let row_data of display_data\" class=\"subgrid-row\" [configs]=\"configs\"\r\n      [internal_configs]=\"internal_configs\" [expand_tracker]=\"expand_tracker\" [edit_tracker]=\"edit_tracker\"\r\n      [store]=\"store\" [row_data]=\"row_data\" [cellclick]=\"cellclick\" [rowselect]=\"rowselect\" [rowdeselect]=\"rowdeselect\"\r\n      [expand]=\"expand\" [rowsave]=\"rowsave\" [rowdelete]=\"rowdelete\">\r\n\r\n    </tr>\r\n  </ng-container>\r\n  <ng-container *ngIf=\"!configs.subgrid\">\r\n    <tr *ngFor=\"let row_data of display_data\"\r\n      [attr.class]=\"configs.row_class_function(row_data) + ' ' + (row_data.row_selected ? configs.css.row_selection_class : '')\"\r\n      (click)=\"selectRow(row_data, $event)\">\r\n      <ng-container *ngIf=\"expand_tracker[row_data.parent_pathx]\">\r\n        <td *ngIf=\"configs.multi_select\" class=\"checkbox_column\">\r\n          <input type=\"checkbox\" [checked]=\"row_data.row_selected\" (click)=\"selectRowOnCheck(row_data, $event)\"\r\n            [attr.disabled]=\"row_data.selection_disabled\">\r\n        </td>\r\n        <td db-tree-cell-actions\r\n          *ngIf=\"((configs.actions.edit || configs.actions.delete || configs.actions.add) && (configs.action_column_position =='first'))\"\r\n          [row_data]=\"row_data\" [configs]=\"configs\" [store]=\"store\" [edit_tracker]=\"edit_tracker\"\r\n          [internal_configs]=\"internal_configs\" [rowdelete]=\"rowdelete\" (canceledit)=\"cancelEdit($event)\"\r\n          (editcomplete)=\"saveRecord($event)\">\r\n        </td>\r\n        <td *ngFor=\"let column of columns; index as i\" class=\"{{column.css_class}}\"\r\n          [ngClass]=\"{'column-hide': column.hidden, 'expand-column': i == 0}\">\r\n          <db-tree-cell [configs]=\"configs\" [column]=\"column\" [index]=\"i\" [row_data]=\"row_data\"\r\n            [expand_tracker]=\"expand_tracker\" [edit_on]=\"edit_tracker[row_data[configs.id_field]]\"\r\n            [cellclick]=\"cellclick\" (rowexpand)=\"onRowExpand($event)\" (rowcollapse)=\"onRowCollapse($event)\"\r\n            (editcomplete)=\"saveRecord($event)\">\r\n          </db-tree-cell>\r\n        </td>\r\n        <td *ngIf=\"configs.show_parent_on_edit && internal_configs.show_parent_col\">\r\n          <select *ngIf=\"edit_tracker[row_data[configs.id_field]]\" [(ngModel)]=\"row_data[configs.parent_id_field]\">\r\n            <option *ngFor=\"let parent of parents\" [value]=\"parent.id\">{{parent.value}}</option>\r\n          </select>\r\n        </td>\r\n\r\n        <!-- Add column to fix UI issue when add row is enabled but don't show when edit is enabled for the row -->\r\n        <td *ngIf=\"internal_configs.show_add_row && !(internal_configs.show_parent_col && configs.show_parent_on_edit)\">\r\n        </td>\r\n\r\n        <td db-tree-cell-actions\r\n          *ngIf=\"((configs.actions.edit || configs.actions.delete || configs.actions.add) && (configs.action_column_position =='last'))\"\r\n          [row_data]=\"row_data\" [configs]=\"configs\" [store]=\"store\" [edit_tracker]=\"edit_tracker\"\r\n          [internal_configs]=\"internal_configs\" [rowdelete]=\"rowdelete\" (canceledit)=\"cancelEdit($event)\"\r\n          (editcomplete)=\"saveRecord($event)\">\r\n        </td>\r\n      </ng-container>\r\n    </tr>\r\n    <tr *ngIf=\"configs.show_summary_row\">\r\n      <td *ngIf=\"configs.multi_select\"></td>\r\n      <td *ngIf=\"(configs.actions.edit || configs.actions.delete || configs.actions.add)\"></td>\r\n      <td *ngFor=\"let column of configs.columns\">\r\n        <div [innerHTML]=\"column.summary_renderer && column.summary_renderer(display_data)\"></div>\r\n      </td>\r\n    </tr>\r\n  </ng-container>\r\n\r\n</ng-container>",
                styles: [".db-tree-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;word-break:keep-all;border:1px solid gray;color:#4b4b4b}tr.selected{background-color:#e2e7eb}tr span.parent_container{padding-left:45px}tr.child{background:#fff}tr.child td:nth-child(2){padding:.875rem 1.25rem .875rem 2.5rem!important}tr.parent{background:#fafbff}tr.subgrid-row{background:#fcfcfc}tr td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.5rem;box-sizing:border-box}tr td.checkbox_column{text-align:center}tr td.expand-column{padding:.3rem}tr td.column-hide{display:none}tr td.clear-left-border{border-left:0!important}tr td.clear-right-border{border-right:0!important}"]
            }] }
];
/** @nocollapse */
TreeBodyComponent.ctorParameters = () => [
    { type: AngularTreeGridService }
];
TreeBodyComponent.propDecorators = {
    store: [{ type: Input }],
    configs: [{ type: Input }],
    expand_tracker: [{ type: Input }],
    edit_tracker: [{ type: Input }],
    internal_configs: [{ type: Input }],
    columns: [{ type: Input }],
    cellclick: [{ type: Input }],
    expand: [{ type: Input }],
    collapse: [{ type: Input }],
    rowdelete: [{ type: Input }],
    rowsave: [{ type: Input }],
    rowadd: [{ type: Input }],
    rowselect: [{ type: Input }],
    rowdeselect: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-cell/tree-cell.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TreeCellComponent {
    constructor() {
        this.rowexpand = new EventEmitter();
        this.rowcollapse = new EventEmitter();
        this.canceledit = new EventEmitter();
        this.editcomplete = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.is_expand_column = this.index === 0;
        this.show_expand_icon = !this.row_data.leaf;
        // If user mentions a node as leaf.
        if (this.configs.load_children_on_expand) {
            this.show_expand_icon = !this.row_data.leaf_node;
        }
        this.cell_value = this.row_data[this.column.name];
    }
    /**
     * @param {?} event
     * @return {?}
     */
    expandRow(event) {
        if (this.index === 0 && (!this.row_data.leaf || this.configs.load_children_on_expand)) {
            this.rowexpand.emit({ event: event, data: this.row_data });
            event.stopPropagation();
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    collapseRow(event) {
        if (this.index === 0 && (!this.row_data.leaf || this.configs.load_children_on_expand)) {
            this.rowcollapse.emit({ event: event, data: this.row_data });
            event.stopPropagation();
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onCellClick(event) {
        this.cellclick.emit({ column: this.column, row: this.row_data, event: event });
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    onEditComplete($event) {
        this.editcomplete.emit({ event: $event, data: this.row_data });
    }
}
TreeCellComponent.decorators = [
    { type: Component, args: [{
                selector: 'db-tree-cell',
                template: "<div (click)=\"onCellClick($event)\">\r\n  <ng-container *ngIf=\"is_expand_column\">\r\n    <div [ngStyle]=\"{'padding-left': row_data.leaf ? row_data.levelx * 20 + 'px' : row_data.levelx * 10 + 'px'}\">\r\n      <ng-container *ngIf=\"!expand_tracker[row_data.pathx]\">\r\n        <span (click)=\"expandRow($event)\">\r\n          <i \r\n            [ngClass]=\"configs.css.expand_class\" \r\n            class=\"expand-icon\" \r\n            aria-hidden=\"true\"\r\n            [ngStyle]=\"{'visibility': row_data.expand_disabled ? 'hidden' : 'visible'}\"\r\n            *ngIf=\"show_expand_icon\"\r\n          ></i>\r\n        </span>\r\n      </ng-container>\r\n      <ng-container *ngIf=\"expand_tracker[row_data.pathx]\">\r\n        <span *ngIf=\"row_data.is_loading\" class=\"childred-loader\"></span>\r\n        <span (click)=\"collapseRow($event)\" *ngIf=\"!row_data.is_loading\">\r\n          <i \r\n            [ngClass]=\"configs.css.collapse_class\" \r\n            class=\"expand-icon\" \r\n            aria-hidden=\"true\"\r\n            [ngStyle]=\"{'visibility': row_data.expand_disabled ? 'hidden' : 'visible'}\"            \r\n            *ngIf=\"show_expand_icon\"\r\n          ></i>\r\n        </span>          \r\n      </ng-container>      \r\n      <ng-container *ngIf=\"!edit_on || !column.editable\" [ngSwitch]=\"column.type\">\r\n        <db-custom-cell-component \r\n          *ngSwitchCase=\"'custom'\"\r\n          [column]=\"column\" \r\n          [row_data]=\"row_data\">\r\n        </db-custom-cell-component>\r\n        <db-tree-cell-view\r\n          *ngSwitchDefault \r\n          [column] = \"column\"\r\n          [row_data] = \"row_data\">\r\n        </db-tree-cell-view>\r\n      </ng-container>\r\n      <ng-container *ngIf=\"edit_on && column.editable\">\r\n          <db-custom-cell-editor-component \r\n            *ngIf=\"column.editor\" \r\n            [cell_value]=\"cell_value\" \r\n            [column]=\"column\" \r\n            [row_data]=\"row_data\"\r\n            (canceledit)=\"canceledit.emit(row_data['pathx'])\"\r\n            (editcomplete)=\"onEditComplete($event)\">\r\n        </db-custom-cell-editor-component>\r\n        <db-tree-cell-editor \r\n            *ngIf=\"!column.editor\"\r\n            [cell_value]=\"cell_value\" \r\n            [row_data]=\"row_data\" \r\n            [column]=\"column\"\r\n            [expandable_column]=true\r\n            (canceledit)=\"canceledit.emit(row_data['pathx'])\"\r\n            (editcomplete)=\"onEditComplete($event)\"\r\n            >\r\n        </db-tree-cell-editor>\r\n      </ng-container>\r\n    </div>\r\n  </ng-container>\r\n  <ng-container *ngIf=\"!is_expand_column\">\r\n    <ng-container *ngIf=\"!edit_on || !column.editable\" [ngSwitch]=\"column.type\">\r\n      <db-custom-cell-component \r\n        *ngSwitchCase=\"'custom'\"\r\n        [column]=\"column\" \r\n        [row_data]=\"row_data\">\r\n      </db-custom-cell-component>\r\n      <db-tree-cell-view\r\n        *ngSwitchDefault \r\n        [column] = \"column\"\r\n        [row_data] = \"row_data\">\r\n      </db-tree-cell-view>\r\n    </ng-container> \r\n\r\n    <ng-container *ngIf=\"edit_on && column.editable\">\r\n        <db-custom-cell-editor-component \r\n          *ngIf=\"column.editor\" \r\n          [cell_value]=\"cell_value\" \r\n          [column]=\"column\" \r\n          [row_data]=\"row_data\"\r\n          (canceledit)=\"canceledit.emit(row_data['pathx'])\"\r\n          (editcomplete)=\"onEditComplete($event)\">\r\n      </db-custom-cell-editor-component>\r\n      <db-tree-cell-editor \r\n          *ngIf=\"!column.editor\"\r\n          [cell_value]=\"cell_value\" \r\n          [row_data]=\"row_data\" \r\n          [column]=\"column\"\r\n          [expandable_column]=false\r\n          (canceledit)=\"canceledit.emit(row_data['pathx'])\"\r\n          (editcomplete)=\"onEditComplete($event)\"\r\n          >\r\n      </db-tree-cell-editor>\r\n    </ng-container> \r\n  </ng-container>\r\n</div>\r\n",
                styles: [".db-tree-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;word-break:keep-all;border:1px solid gray;color:#4b4b4b}i.expand-icon{margin-right:8px}i.plus{border:1px solid transparent;margin-right:32px}i.plus:before{content:'';width:18px;height:1px;border-top:2px solid #222;display:block;position:absolute;margin-top:-15px;margin-left:6px}i.plus:after{content:'';width:1px;height:18px;border-right:2px solid #222;display:block;position:absolute;margin-top:-23px;margin-left:14px}i.minus{border:1px solid transparent;margin-right:32px}i.minus:before{content:'';width:18px;height:1px;border-top:2px solid #222;display:block;position:absolute;margin-top:-15px;margin-left:6px}span.childred-loader{border:3px solid #f3f3f3;-webkit-animation:1s linear infinite spin;animation:1s linear infinite spin;border-top:3px solid #555;border-radius:50%;width:10px;height:10px;display:inline-block;margin-right:5px}@-webkit-keyframes spin{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}@keyframes spin{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}"]
            }] }
];
/** @nocollapse */
TreeCellComponent.ctorParameters = () => [];
TreeCellComponent.propDecorators = {
    configs: [{ type: Input }],
    index: [{ type: Input }],
    row_data: [{ type: Input }],
    column: [{ type: Input }],
    expand_tracker: [{ type: Input }],
    cellclick: [{ type: Input }],
    edit_on: [{ type: Input }],
    rowexpand: [{ type: Output }],
    rowcollapse: [{ type: Output }],
    canceledit: [{ type: Output }],
    editcomplete: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-cell/components/tree-cell-view/default/tree-cell-view.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TreeCellViewComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
TreeCellViewComponent.decorators = [
    { type: Component, args: [{
                selector: 'db-tree-cell-view',
                template: "<span [innerHTML]=\"column.renderer ? column.renderer(row_data[column.name], row_data) : row_data[column.name]\"></span>\r\n",
                styles: [""]
            }] }
];
/** @nocollapse */
TreeCellViewComponent.ctorParameters = () => [];
TreeCellViewComponent.propDecorators = {
    column: [{ type: Input }],
    row_data: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-cell/components/tree-cell-view/custom/custom-tree-cell.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CustomCellViewComponent {
    /**
     * @param {?} resolver
     */
    constructor(resolver) {
        this.resolver = resolver;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.column.component && !this.custom_component) {
            this.createCustomComponent();
            this.callOnComponentInit();
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.custom_component) {
            this.custom_component.destroy();
        }
    }
    /**
     * @protected
     * @return {?}
     */
    createCustomComponent() {
        /** @type {?} */
        const componentFactory = this.resolver.resolveComponentFactory(this.column.component);
        this.custom_component = this.custom_view.createComponent(componentFactory);
    }
    /**
     * @protected
     * @return {?}
     */
    callOnComponentInit() {
        this.column.on_component_init && this.column.on_component_init(this.custom_component.instance);
        this.custom_component.instance.cell_value = this.row_data[this.column.name];
        this.custom_component.instance.row_data = this.row_data;
        this.custom_component.instance.column = this.column;
    }
}
CustomCellViewComponent.decorators = [
    { type: Component, args: [{
                selector: 'db-custom-cell-component',
                template: `
      <ng-template #customView></ng-template>
    `
            }] }
];
/** @nocollapse */
CustomCellViewComponent.ctorParameters = () => [
    { type: ComponentFactoryResolver }
];
CustomCellViewComponent.propDecorators = {
    column: [{ type: Input }],
    row_data: [{ type: Input }],
    custom_view: [{ type: ViewChild, args: ['customView', { read: ViewContainerRef },] }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-cell/components/tree-cell-actions/tree-cell-actions.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TreeCellActionsComponent {
    constructor() {
        this.editcomplete = new EventEmitter();
        this.canceledit = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.display_data = this.store.getDisplayData();
    }
    /**
     * @param {?} index
     * @param {?} row_data
     * @return {?}
     */
    enableEdit(index, row_data) {
        this.edit_tracker[index] = true;
        // Only if edit_parent is true.
        if (this.configs.actions.edit_parent) {
            this.internal_configs.show_parent_col = true;
            this.internal_configs.current_edited_row = Object.assign({}, row_data);
        }
    }
    /**
     * @param {?} pathx
     * @return {?}
     */
    findRecordIndex(pathx) {
        for (const index in this.store.processed_data) {
            if (this.store.processed_data[index].pathx === pathx) {
                return Number(index);
            }
        }
    }
    /**
     * @param {?} rec
     * @return {?}
     */
    deleteRecord(rec) {
        /** @type {?} */
        const index = this.findRecordIndex(rec.pathx);
        if (this.configs.actions.resolve_delete) {
            /** @type {?} */
            const promise = new Promise((/**
             * @param {?} resolve
             * @param {?} reject
             * @return {?}
             */
            (resolve, reject) => {
                this.rowdelete.emit({
                    data: rec,
                    resolve: resolve
                });
            }));
            promise.then((/**
             * @return {?}
             */
            () => {
                this.store.processed_data.splice(index, 1);
                this.deleteChildren(rec);
                this.store.refreshDisplayData();
            })).catch((/**
             * @param {?} err
             * @return {?}
             */
            (err) => { }));
        }
        else {
            this.store.processed_data.splice(index, 1);
            this.deleteChildren(rec);
            this.store.refreshDisplayData();
            this.rowdelete.emit(rec);
        }
    }
    /**
     * @param {?} parent
     * @return {?}
     */
    deleteChildren(parent) {
        /** @type {?} */
        const display_data = [...this.store.processed_data];
        /** @type {?} */
        const pathx = parent.pathx;
        for (let index = 0; index < display_data.length; index++) {
            /** @type {?} */
            const record = display_data[index];
            if (record.pathx.includes(pathx)) {
                /** @type {?} */
                const index = this.findRecordIndex(record.pathx);
                this.store.processed_data.splice(index, 1);
            }
        }
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    saveRecord($event) {
        this.editcomplete.emit({ event: $event, data: this.row_data });
    }
}
TreeCellActionsComponent.decorators = [
    { type: Component, args: [{
                selector: '[db-tree-cell-actions]',
                template: "<ng-container *ngIf=\"configs.actions.edit && configs.row_edit_function(row_data)\">\r\n  <div *ngIf=\"!edit_tracker[row_data[configs.id_field]]\" class=\"icon-container\">\r\n    <i (click)=\"enableEdit(row_data[configs.id_field], row_data)\" *ngIf=\"configs.css.edit_class\" title=\"Edit row\" class=\"{{this.configs.css.edit_class}}\" aria-hidden=\"true\" ></i>\r\n    <svg (click)=\"enableEdit(row_data[configs.id_field], row_data)\" *ngIf=\"!configs.css.edit_class\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"><title>Edit row</title><g data-name=\"Layer 2\"><g data-name=\"edit\"><rect width=\"24\" height=\"24\" opacity=\"0\"/><path d=\"M19.4 7.34L16.66 4.6A2 2 0 0 0 14 4.53l-9 9a2 2 0 0 0-.57 1.21L4 18.91a1 1 0 0 0 .29.8A1 1 0 0 0 5 20h.09l4.17-.38a2 2 0 0 0 1.21-.57l9-9a1.92 1.92 0 0 0-.07-2.71zM9.08 17.62l-3 .28.27-3L12 9.32l2.7 2.7zM16 10.68L13.32 8l1.95-2L18 8.73z\"/></g></g></svg>             \r\n  </div>\r\n  <ng-container *ngIf=\"edit_tracker[row_data[configs.id_field]]\">\r\n    <div class=\"icon-container\">\r\n      <i (click)=\"saveRecord($event)\" *ngIf=\"configs.css.save_class\" title=\"Save row\" class=\"{{this.configs.css.save_class}}\" aria-hidden=\"true\"></i>\r\n      <svg (click)=\"saveRecord($event)\" title=\"Save row\" *ngIf=\"!configs.css.save_class\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"><title>Save row</title><g data-name=\"Layer 2\"><g data-name=\"save\"><rect width=\"24\" height=\"24\" opacity=\"0\"/><path d=\"M20.12 8.71l-4.83-4.83A3 3 0 0 0 13.17 3H6a3 3 0 0 0-3 3v12a3 3 0 0 0 3 3h12a3 3 0 0 0 3-3v-7.17a3 3 0 0 0-.88-2.12zM10 19v-2h4v2zm9-1a1 1 0 0 1-1 1h-2v-3a1 1 0 0 0-1-1H9a1 1 0 0 0-1 1v3H6a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h2v5a1 1 0 0 0 1 1h4a1 1 0 0 0 0-2h-3V5h3.17a1.05 1.05 0 0 1 .71.29l4.83 4.83a1 1 0 0 1 .29.71z\"/></g></g></svg>\r\n    </div>\r\n    <div class=\"icon-container\">\r\n      <i (click)=\"canceledit.emit(row_data)\" *ngIf=\"configs.css.cancel_class\" title=\"Cancel row\" class=\"{{this.configs.css.cancel_class}}\" aria-hidden=\"true\"></i>\r\n      <svg (click)=\"canceledit.emit(row_data)\" *ngIf=\"!configs.css.cancel_class\" title=\"Cancel row\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"><title>Cancel row</title><g data-name=\"Layer 2\"><g data-name=\"close\"><rect width=\"24\" height=\"24\" transform=\"rotate(180 12 12)\" opacity=\"0\"/><path d=\"M13.41 12l4.3-4.29a1 1 0 1 0-1.42-1.42L12 10.59l-4.29-4.3a1 1 0 0 0-1.42 1.42l4.3 4.29-4.3 4.29a1 1 0 0 0 0 1.42 1 1 0 0 0 1.42 0l4.29-4.3 4.29 4.3a1 1 0 0 0 1.42 0 1 1 0 0 0 0-1.42z\"/></g></g></svg>\r\n    </div>\r\n  </ng-container>\r\n</ng-container>            \r\n<div \r\n  class=\"icon-container\"\r\n  *ngIf=\"\r\n      configs.actions.delete && \r\n      !edit_tracker[row_data[configs.id_field]] && \r\n      configs.row_delete_function(row_data)\">\r\n  <i *ngIf=\"configs.css.delete_class\" title=\"Delete row\" (click)=\"deleteRecord(row_data)\" class=\"{{this.configs.css.delete_class}}\" aria-hidden=\"true\"></i>\r\n  <svg *ngIf=\"!configs.css.delete_class\" title=\"Delete row\" (click)=\"deleteRecord(row_data)\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"><title>Delete row</title><g data-name=\"Layer 2\"><g data-name=\"trash-2\"><rect width=\"24\" height=\"24\" opacity=\"0\"/><path d=\"M21 6h-5V4.33A2.42 2.42 0 0 0 13.5 2h-3A2.42 2.42 0 0 0 8 4.33V6H3a1 1 0 0 0 0 2h1v11a3 3 0 0 0 3 3h10a3 3 0 0 0 3-3V8h1a1 1 0 0 0 0-2zM10 4.33c0-.16.21-.33.5-.33h3c.29 0 .5.17.5.33V6h-4zM18 19a1 1 0 0 1-1 1H7a1 1 0 0 1-1-1V8h12z\"/><path d=\"M9 17a1 1 0 0 0 1-1v-4a1 1 0 0 0-2 0v4a1 1 0 0 0 1 1z\"/><path d=\"M15 17a1 1 0 0 0 1-1v-4a1 1 0 0 0-2 0v4a1 1 0 0 0 1 1z\"/></g></g></svg>            \r\n</div>",
                styles: ["svg{width:25px;padding-right:5px}div.icon-container{display:inline-block;width:50%;text-align:center;color:#000;cursor:pointer}"]
            }] }
];
/** @nocollapse */
TreeCellActionsComponent.ctorParameters = () => [];
TreeCellActionsComponent.propDecorators = {
    store: [{ type: Input }],
    edit_tracker: [{ type: Input }],
    internal_configs: [{ type: Input }],
    configs: [{ type: Input }],
    rowdelete: [{ type: Input }],
    row_data: [{ type: Input }],
    editcomplete: [{ type: Output }],
    canceledit: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-cell/components/tree-cell-editor/default/default-editor.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class DefaultEditor {
    constructor() {
        this.canceledit = new EventEmitter();
        this.editcomplete = new EventEmitter();
        this.cellclick = new EventEmitter();
    }
}
DefaultEditor.propDecorators = {
    canceledit: [{ type: Output }],
    editcomplete: [{ type: Output }],
    cellclick: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-cell/components/tree-cell-editor/custom/custom-tree-cell-Editor.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class CustomCellEditorComponent extends DefaultEditor {
    /**
     * @param {?} resolver
     */
    constructor(resolver) {
        super();
        this.resolver = resolver;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.column.editor && !this.custom_component) {
            this.createCustomComponent();
            this.callOnComponentInit();
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.custom_component) {
            this.custom_component.destroy();
        }
    }
    /**
     * @protected
     * @return {?}
     */
    createCustomComponent() {
        /** @type {?} */
        const componentFactory = this.resolver.resolveComponentFactory(this.column.editor);
        this.custom_component = this.custom_view.createComponent(componentFactory);
    }
    /**
     * @protected
     * @return {?}
     */
    callOnComponentInit() {
        this.column.on_component_init && this.column.on_component_init(this.custom_component.instance);
        this.custom_component.instance.cell_value = this.cell_value;
        this.custom_component.instance.row_data = this.row_data;
        this.custom_component.instance.column = this.column;
        this.custom_component.instance.editcomplete.subscribe((/**
         * @param {?} event
         * @return {?}
         */
        (event) => this.editcomplete.emit(event)));
        this.custom_component.instance.canceledit.subscribe((/**
         * @param {?} event
         * @return {?}
         */
        (event) => this.canceledit.emit(event)));
        this.custom_component.instance.cellclick.subscribe((/**
         * @param {?} event
         * @return {?}
         */
        (event) => this.cellclick.emit(event)));
    }
}
CustomCellEditorComponent.decorators = [
    { type: Component, args: [{
                selector: 'db-custom-cell-editor-component',
                template: `
      <ng-template #customView></ng-template>
    `
            }] }
];
/** @nocollapse */
CustomCellEditorComponent.ctorParameters = () => [
    { type: ComponentFactoryResolver }
];
CustomCellEditorComponent.propDecorators = {
    column: [{ type: Input }],
    cell_value: [{ type: Input }],
    row_data: [{ type: Input }],
    custom_view: [{ type: ViewChild, args: ['customView', { read: ViewContainerRef },] }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-cell/components/tree-cell-editor/default/cell-editor/tree-cell-editor.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TreeCellEditorComponent extends DefaultEditor {
    constructor() {
        super();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
TreeCellEditorComponent.decorators = [
    { type: Component, args: [{
                selector: 'db-tree-cell-editor',
                template: "<input type=\"text\" \r\n    [(ngModel)]=\"row_data[column.name]\" \r\n    [ngClass]=\"{'cell-default': true, 'expandable-editor': expandable_column}\"\r\n    (click)=\"cellclick.emit($event)\"\r\n    (keydown.enter)=\"editcomplete.emit($event)\"\r\n    (keydown.esc)=\"canceledit.emit()\"\r\n    size=\"1\"\r\n    >",
                styles: ["input.cell-default{padding:5px;box-sizing:border-box;width:100%}input.expandable-editor{width:calc(100% - 18px)}"]
            }] }
];
/** @nocollapse */
TreeCellEditorComponent.ctorParameters = () => [];
TreeCellEditorComponent.propDecorators = {
    cell_value: [{ type: Input }],
    row_data: [{ type: Input }],
    column: [{ type: Input }],
    expandable_column: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-cell/tree-cell.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TreeCellModule {
}
TreeCellModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    TreeCellComponent,
                    TreeCellViewComponent,
                    CustomCellViewComponent,
                    TreeCellActionsComponent,
                    CustomCellEditorComponent,
                    TreeCellEditorComponent
                ],
                imports: [
                    CommonModule,
                    FormsModule
                ],
                exports: [
                    TreeCellComponent,
                    CustomCellViewComponent,
                    CustomCellEditorComponent,
                    TreeCellEditorComponent,
                    TreeCellActionsComponent
                ],
                providers: [AngularTreeGridService]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-body/components/add-row/add-row.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AddRowComponent {
    constructor() {
        this.row_data = {};
        this.parents = [];
        this.rowadd = new EventEmitter();
        this.canceledit = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.raw_data = this.store.getRawData();
        this.columns.forEach((/**
         * @param {?} column
         * @return {?}
         */
        column => {
            this.row_data[column.name] = '';
        }));
        this.parents = this.raw_data.map((/**
         * @param {?} element
         * @return {?}
         */
        element => {
            return {
                'id': element[this.configs.id_field],
                'value': element[this.configs.parent_display_field]
            };
        }));
    }
    /**
     * @param {?} e
     * @return {?}
     */
    saveAddRecord(e) {
        this.raw_data.push(this.row_data);
        this.rowadd.emit(this.row_data);
    }
    /**
     * @return {?}
     */
    cancelAddEdit() {
        this.internal_configs.show_add_row = false;
    }
}
AddRowComponent.decorators = [
    { type: Component, args: [{
                selector: '[db-add-row]',
                template: "<td *ngIf=\"configs.multi_select\"></td>\r\n<td>\r\n  <div class=\"icon-container\">\r\n    <i (click)=\"saveAddRecord($event)\" *ngIf=\"configs.css.save_class\" title=\"Save row\" class=\"{{this.configs.css.save_class}}\" aria-hidden=\"true\"></i>\r\n    <svg (click)=\"saveAddRecord($event)\" title=\"Save row\" *ngIf=\"!configs.css.save_class\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"><title>Save row</title><g data-name=\"Layer 2\"><g data-name=\"save\"><rect width=\"24\" height=\"24\" opacity=\"0\"/><path d=\"M20.12 8.71l-4.83-4.83A3 3 0 0 0 13.17 3H6a3 3 0 0 0-3 3v12a3 3 0 0 0 3 3h12a3 3 0 0 0 3-3v-7.17a3 3 0 0 0-.88-2.12zM10 19v-2h4v2zm9-1a1 1 0 0 1-1 1h-2v-3a1 1 0 0 0-1-1H9a1 1 0 0 0-1 1v3H6a1 1 0 0 1-1-1V6a1 1 0 0 1 1-1h2v5a1 1 0 0 0 1 1h4a1 1 0 0 0 0-2h-3V5h3.17a1.05 1.05 0 0 1 .71.29l4.83 4.83a1 1 0 0 1 .29.71z\"/></g></g></svg>\r\n  </div>\r\n  <div class=\"icon-container\">\r\n    <i (click)=\"cancelAddEdit()\" *ngIf=\"configs.css.cancel_class\" title=\"Cancel row\" class=\"{{this.configs.css.cancel_class}}\" aria-hidden=\"true\"></i>\r\n    <svg (click)=\"cancelAddEdit()\" *ngIf=\"!configs.css.cancel_class\" title=\"Cancel row\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 24 24\"><title>Cancel row</title><g data-name=\"Layer 2\"><g data-name=\"close\"><rect width=\"24\" height=\"24\" transform=\"rotate(180 12 12)\" opacity=\"0\"/><path d=\"M13.41 12l4.3-4.29a1 1 0 1 0-1.42-1.42L12 10.59l-4.29-4.3a1 1 0 0 0-1.42 1.42l4.3 4.29-4.3 4.29a1 1 0 0 0 0 1.42 1 1 0 0 0 1.42 0l4.29-4.3 4.29 4.3a1 1 0 0 0 1.42 0 1 1 0 0 0 0-1.42z\"/></g></g></svg>\r\n  </div>\r\n</td>\r\n<td *ngFor=\"let column of columns\" [ngClass]=\"{'column-hide': column.hidden}\" >\r\n  <div *ngIf=\"column.editable\">\r\n    <db-custom-cell-editor-component \r\n        *ngIf=\"column.editor\"\r\n        [cell_value]=\"\" \r\n        [column]=\"column\" \r\n        [row_data]=\"row_data\"\r\n        (canceledit)=\"cancelAddEdit()\"\r\n        (editcomplete)=\"saveAddRecord($event)\">\r\n    </db-custom-cell-editor-component>\r\n    <db-tree-cell-editor \r\n        *ngIf=\"!column.editor\"\r\n        [cell_value]=\"\" \r\n        [row_data]=\"row_data\" \r\n        [column]=\"column\"\r\n        (canceledit)=\"cancelAddEdit()\"\r\n        (editcomplete)=\"saveAddRecord($event)\"\r\n        >\r\n    </db-tree-cell-editor>\r\n  </div>\r\n</td>\r\n<td>\r\n  <select [(ngModel)]=\"row_data[configs.parent_id_field]\">\r\n    <option *ngFor=\"let parent of parents\" [value]=\"parent.id\">{{parent.value}}</option>\r\n  </select>\r\n</td>",
                encapsulation: ViewEncapsulation.None,
                styles: [".db-tree-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;word-break:keep-all;border:1px solid gray;color:#4b4b4b}tr.selected{background-color:#e2e7eb}tr span.parent_container{padding-left:45px}tr.child{background:#fff}tr.child td:nth-child(2){padding:.875rem 1.25rem .875rem 2.5rem!important}tr.parent{background:#fafbff}tr.subgrid-row{background:#fcfcfc}tr td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.5rem;box-sizing:border-box}tr td.checkbox_column{text-align:center}tr td.expand-column{padding:.3rem}tr td.column-hide{display:none}tr td.clear-left-border{border-left:0!important}tr td.clear-right-border{border-right:0!important}svg{width:25px;padding-right:4px}div.icon-container{display:inline-block;width:50%;text-align:center}"]
            }] }
];
/** @nocollapse */
AddRowComponent.ctorParameters = () => [];
AddRowComponent.propDecorators = {
    store: [{ type: Input }],
    columns: [{ type: Input }],
    configs: [{ type: Input }],
    internal_configs: [{ type: Input }],
    rowadd: [{ type: Output }],
    canceledit: [{ type: Output }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-body/components/filter-row/filter-row.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class FilterRowComponent {
    /**
     * @param {?} angularTreeGridService
     */
    constructor(angularTreeGridService) {
        this.angularTreeGridService = angularTreeGridService;
        this.search_values = {};
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.columns.forEach((/**
         * @param {?} column
         * @return {?}
         */
        column => {
            this.search_values[column.name] = '';
        }));
    }
    /**
     * @return {?}
     */
    filter() {
        this.store.filterBy(this.columns, Object.values(this.search_values));
        // Don't expand for subgrid.
        if (!this.configs.subgrid) {
            this.angularTreeGridService.expandAll(this.expand_tracker);
        }
    }
}
FilterRowComponent.decorators = [
    { type: Component, args: [{
                selector: '[db-filter-row]',
                template: "<td *ngIf=\"configs.multi_select\"></td>\r\n<td\r\n  *ngIf=\"(configs.actions.edit || configs.actions.delete || configs.actions.add) && (configs.action_column_position =='first')\">\r\n</td>\r\n<td *ngFor=\"let column of columns\">\r\n  <div *ngIf=\"column.filter\">\r\n    <input type=\"text\" (keyup)=\"filter()\" [(ngModel)]=\"search_values[column.name]\">\r\n  </div>\r\n</td>\r\n<!-- Add column to fix UI issue when add row is enabled or Edit is enabled -->\r\n<td *ngIf=\"internal_configs.show_add_row || (internal_configs.show_parent_col && configs.show_parent_on_edit)\"></td>\r\n<td\r\n  *ngIf=\"(configs.actions.edit || configs.actions.delete || configs.actions.add) && (configs.action_column_position =='last')\">\r\n</td>",
                styles: [".db-tree-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;word-break:keep-all;border:1px solid gray;color:#4b4b4b}tr.selected{background-color:#e2e7eb}tr span.parent_container{padding-left:45px}tr.child{background:#fff}tr.child td:nth-child(2){padding:.875rem 1.25rem .875rem 2.5rem!important}tr.parent{background:#fafbff}tr.subgrid-row{background:#fcfcfc}tr td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.5rem;box-sizing:border-box}tr td.checkbox_column{text-align:center}tr td.expand-column{padding:.3rem}tr td.column-hide{display:none}tr td.clear-left-border{border-left:0!important}tr td.clear-right-border{border-right:0!important}td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.2rem}td input{width:100%;padding:.1rem;box-sizing:border-box;-webkit-box-sizing:border-box;-moz-box-sizing:border-box}"]
            }] }
];
/** @nocollapse */
FilterRowComponent.ctorParameters = () => [
    { type: AngularTreeGridService }
];
FilterRowComponent.propDecorators = {
    store: [{ type: Input }],
    columns: [{ type: Input }],
    expand_tracker: [{ type: Input }],
    configs: [{ type: Input }],
    internal_configs: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/subgrid/subgrid.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SubgridComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @param {?} $event
     * @return {?}
     */
    saveRecord($event) {
        /** @type {?} */
        const element = $event.data;
        if (this.configs.actions.resolve_edit) {
            /** @type {?} */
            const promise = new Promise((/**
             * @param {?} resolve
             * @param {?} reject
             * @return {?}
             */
            (resolve, reject) => {
                this.rowsave.emit({
                    data: element,
                    resolve: resolve
                });
            }));
            promise.then((/**
             * @return {?}
             */
            () => {
                this.checkAndRefreshData(element);
            })).catch((/**
             * @param {?} err
             * @return {?}
             */
            (err) => { }));
        }
        else {
            this.checkAndRefreshData(element);
            this.rowsave.emit(element);
        }
    }
    /**
     * @param {?} element
     * @return {?}
     */
    checkAndRefreshData(element) {
        this.edit_tracker[element[this.configs.id_field]] = false;
        this.internal_configs.show_parent_col = false;
        // Only refresh if Parent has been changed.
        if (this.internal_configs.current_edited_row[this.configs.parent_id_field]
            !== element[this.configs.parent_id_field]) {
            this.refreshData(element);
        }
    }
    /**
     * @param {?} element
     * @return {?}
     */
    refreshData(element) {
        // If edit parent is not true then don't refresh.
        if (!this.configs.actions.edit_parent) {
            return;
        }
        element[this.configs.parent_id_field] = parseInt(element[this.configs.parent_id_field], 10);
        this.expand_tracker = {};
        this.edit_tracker = {};
        this.store.processData(this.store.getRawData(), this.expand_tracker, this.configs, this.edit_tracker, this.internal_configs);
    }
    /**
     * @param {?} row_data
     * @return {?}
     */
    cancelEdit(row_data) {
        /** @type {?} */
        const index = row_data[this.configs.id_field];
        // Cancel all changes ie copy from back up.
        Object.assign(row_data, this.internal_configs.current_edited_row);
        this.edit_tracker[index] = false;
        this.internal_configs.show_parent_col = false;
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onRowExpand(event) {
        /** @type {?} */
        const row_data = event.data;
        /** @type {?} */
        const promise = new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            this.expand.emit({
                data: row_data,
                resolve: resolve
            });
        }));
        this.expand_tracker[row_data.pathx] = true;
        /** @type {?} */
        const blank_row = this.store.showBlankRow(row_data);
        blank_row.loading_children = true;
        // Add Child rows to the table.
        promise.then((/**
         * @param {?} child_rows
         * @return {?}
         */
        (child_rows) => {
            blank_row.loading_children = false;
            if (child_rows) {
                child_rows.map((/**
                 * @param {?} child
                 * @return {?}
                 */
                child => {
                    child.leaf = true;
                }));
                blank_row.children = child_rows;
            }
            else {
                // Persist old children. If didn't exist then assign blank array.
                if (!blank_row.children) {
                    blank_row.children = [];
                }
            }
        })).catch((/**
         * @param {?} err
         * @return {?}
         */
        (err) => { }));
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onRowCollapse(event) {
        /** @type {?} */
        const row_data = event.data;
        this.expand_tracker[row_data.pathx] = false;
    }
    /**
     * @param {?} row_data
     * @param {?} event
     * @return {?}
     */
    selectRowOnCheck(row_data, event) {
        if (event.target.checked) {
            row_data.row_selected = true;
            this.rowselect.emit({ data: row_data, event: event });
        }
        else {
            row_data.row_selected = false;
            this.rowdeselect.emit({ data: row_data, event: event });
        }
        this.setSelectAllConfig();
    }
    /**
     * Set Select All config on Select change.
     *
     * @return {?}
     */
    setSelectAllConfig() {
        /** @type {?} */
        let select_all = true;
        this.store.getDisplayData().forEach((/**
         * @param {?} data
         * @return {?}
         */
        data => {
            if (!data.row_selected) {
                select_all = false;
            }
        }));
        this.internal_configs.all_selected = select_all;
    }
}
SubgridComponent.decorators = [
    { type: Component, args: [{
                selector: '[db-subgrid]',
                template: "<ng-container *ngIf=\"expand_tracker[row_data.parent_pathx]\">\r\n\r\n  <!-- Expandable Row -->\r\n  <ng-container *ngIf=\"!row_data.leaf\">\r\n    <td *ngIf=\"configs.multi_select\" class=\"checkbox_column\">\r\n      <input type=\"checkbox\" [checked]=\"row_data.row_selected\" (click)=\"selectRowOnCheck(row_data, $event)\" \r\n        [attr.disabled]=\"row_data.selection_disabled\">\r\n    </td>\r\n    <td db-tree-cell-actions \r\n      *ngIf=\"(configs.actions.edit || configs.actions.delete || configs.actions.add)\"\r\n      [row_data]=\"row_data\"\r\n      [configs]=\"configs\"\r\n      [store]=\"store\"\r\n      [edit_tracker]=\"edit_tracker\"\r\n      [internal_configs]=\"internal_configs\"\r\n      [rowdelete]=\"rowdelete\"\r\n      (canceledit)=\"cancelEdit($event)\" \r\n      (editcomplete)=\"saveRecord($event)\"\r\n      >\r\n    </td>\r\n    <td *ngFor=\"let column of configs.columns; index as i\" \r\n      [ngClass]=\"{'column-hide': column.hidden, 'expand-column': i == 0}\">\r\n      <db-tree-cell\r\n        [configs]=\"configs\"\r\n        [column]=\"column\"\r\n        [index]=\"i\"\r\n        [row_data]=\"row_data\"\r\n        [expand_tracker]=\"expand_tracker\"\r\n        [edit_on]=\"edit_tracker[row_data[configs.id_field]]\"\r\n        [cellclick]=\"cellclick\"\r\n        (rowexpand)=\"onRowExpand($event)\"\r\n        (rowcollapse)=\"onRowCollapse($event)\"\r\n        (editcomplete)=\"saveRecord($event)\"\r\n      >\r\n      </db-tree-cell>\r\n    </td>\r\n  </ng-container>\r\n\r\n  <!-- Subgrid Rows -->\r\n  <ng-container *ngIf=\"row_data.leaf\">    \r\n    <td *ngIf=\"configs.multi_select\"></td>\r\n    <td *ngIf=\"(configs.actions.edit || configs.actions.delete || configs.actions.add)\"></td>\r\n    <td [attr.colspan]=\"configs.columns.length\" class=\"subgrid-column\">\r\n        <table class=\"subgrid-table\">\r\n          <thead db-subgrid-head\r\n            [row_data]=\"row_data\"\r\n            [configs]=\"configs\">\r\n            \r\n          </thead>\r\n          <tbody db-subgrid-body\r\n            [configs]=\"configs\"\r\n            [expand_tracker]=\"expand_tracker\"\r\n            [cellclick]=\"cellclick\"\r\n            [row_data]=\"row_data\">\r\n          </tbody>            \r\n        </table>\r\n    </td>    \r\n  </ng-container>  \r\n</ng-container>",
                styles: ["tr.selected{background-color:#e2e7eb}tr span.parent_container{padding-left:45px}tr.child{background:#fff}tr.child td:nth-child(2){padding:.875rem 1.25rem .875rem 2.5rem!important}tr.parent{background:#fafbff}tr.subgrid-row{background:#fcfcfc}tr td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.5rem;box-sizing:border-box}tr td.checkbox_column{text-align:center}tr td.expand-column{padding:.3rem}tr td.column-hide{display:none}tr td.clear-left-border{border-left:0!important}tr td.clear-right-border{border-right:0!important}.db-tree-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;word-break:keep-all;border:1px solid gray;color:#4b4b4b}tr{background:#fff}tr th{font-size:1rem;font-weight:600;line-height:1.25;color:#181818;border:1px solid #cdd5dc;vertical-align:middle;position:relative;box-sizing:border-box}tr th div{padding:.5rem}tr th.column-hide{display:none}tr th.action-column span.icon-container{cursor:pointer}tr th i.plus{border:1px solid transparent}tr th i.plus:before{content:'';width:18px;height:1px;border-top:2px solid #222;display:block;position:absolute;margin-top:-15px;margin-left:6px}tr th i.plus:after{content:'';width:1px;height:18px;border-right:2px solid #222;display:block;position:absolute;margin-top:-23px;margin-left:14px}th.clear-left-border{border-left:0!important}th.clear-right-border{border-right:0!important}.column-hide{display:none}svg{width:25px;padding-right:3px}td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.5rem;box-sizing:border-box}td.checkbox_column{text-align:center}td.expand-column{padding:.3rem}td.subgrid-column{padding:0}td.column-hide{display:none}td.clear-left-border{border-left:0!important}td.clear-right-border{border-right:0!important}td table.subgrid-table{border-collapse:collapse;width:100%}"]
            }] }
];
/** @nocollapse */
SubgridComponent.ctorParameters = () => [];
SubgridComponent.propDecorators = {
    store: [{ type: Input }],
    configs: [{ type: Input }],
    expand_tracker: [{ type: Input }],
    edit_tracker: [{ type: Input }],
    internal_configs: [{ type: Input }],
    row_data: [{ type: Input }],
    cellclick: [{ type: Input }],
    expand: [{ type: Input }],
    rowselect: [{ type: Input }],
    rowdeselect: [{ type: Input }],
    rowsave: [{ type: Input }],
    rowdelete: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/subgrid/components/subgrid-head/subgrid-head.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SubgridHeadComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
    /**
     * @param {?} row_data
     * @param {?} column
     * @return {?}
     */
    sortColumn(row_data, column) {
        /** @type {?} */
        const sort_by = column.name;
        // If already sorted then reverse.
        column.sort_type = column.sorted ? !column.sort_type : 1;
        column.sorted = 1;
        column.sort_type ? row_data.children.sort((/**
         * @param {?} a
         * @param {?} b
         * @return {?}
         */
        (a, b) => (a[sort_by] > b[sort_by]) ? 1 : ((b[sort_by] > a[sort_by]) ? -1 : 0))) :
            row_data.children.sort((/**
             * @param {?} a
             * @param {?} b
             * @return {?}
             */
            (a, b) => (a[sort_by] < b[sort_by]) ? 1 : ((b[sort_by] < a[sort_by]) ? -1 : 0)));
    }
}
SubgridHeadComponent.decorators = [
    { type: Component, args: [{
                selector: '[db-subgrid-head]',
                template: "<tr>\r\n  <th *ngFor=\"let column of configs.subgrid_config.columns\"\r\n    (click)=\"sortColumn(row_data, column)\" width=\"{{column.width ? column.width : 'auto'}}\"\r\n    [ngClass]=\"{'sorted': column.sorted,'sortable': column.sortable, 'column-hide': column.hidden}\">\r\n    {{column.header}}\r\n    <span *ngIf=\"column.sortable\" [ngClass]=\"column.sorted && column.sort_type == 0?'arrow-down active':'arrow-down'\"></span>\r\n    <span *ngIf=\"column.sortable\" [ngClass]=\"column.sorted && column.sort_type == 1?'arrow-up active':'arrow-up'\"></span>\r\n  </th>\r\n</tr>",
                styles: [".db-tree-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;word-break:keep-all;border:1px solid gray;color:#4b4b4b}tr{background:#fff}tr th{font-size:1rem;font-weight:600;line-height:1.25;color:#181818;border:1px solid #cdd5dc;vertical-align:middle;position:relative;box-sizing:border-box}tr th div{padding:.5rem}tr th.column-hide{display:none}tr th.action-column span.icon-container{cursor:pointer}tr th i.plus{border:1px solid transparent}tr th i.plus:before{content:'';width:18px;height:1px;border-top:2px solid #222;display:block;position:absolute;margin-top:-15px;margin-left:6px}tr th i.plus:after{content:'';width:1px;height:18px;border-right:2px solid #222;display:block;position:absolute;margin-top:-23px;margin-left:14px}th.clear-left-border{border-left:0!important}th.clear-right-border{border-right:0!important}.column-hide{display:none}svg{width:25px;padding-right:3px}th.sortable{cursor:pointer}th.sortable:hover span.arrow-up{border-bottom:6px solid #afafaf}th.sortable:hover span.arrow-down{border-top:6px solid #afafaf}th span.arrow-up{width:0;height:0;border-left:5px solid transparent;border-right:5px solid transparent;border-bottom:6px solid #ddd;position:relative;top:-18px}th span.arrow-up.active{border-bottom:6px solid #8a8989!important}th span.arrow-down{width:0;height:0;border-left:5px solid transparent;border-right:5px solid transparent;border-top:6px solid #ddd;position:relative;left:10px;top:17px}th span.arrow-down.active{border-top:6px solid #8a8989!important}"]
            }] }
];
/** @nocollapse */
SubgridHeadComponent.ctorParameters = () => [];
SubgridHeadComponent.propDecorators = {
    configs: [{ type: Input }],
    row_data: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/subgrid/components/subgrid-body/subgrid-body.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SubgridBodyComponent {
    constructor() { }
    /**
     * @return {?}
     */
    ngOnInit() {
    }
}
SubgridBodyComponent.decorators = [
    { type: Component, args: [{
                selector: '[db-subgrid-body]',
                template: "<ng-container *ngIf=\"row_data.loading_children\">\r\n  <tr>\r\n    <td [attr.colspan]=\"configs.subgrid_config.columns.length\" \r\n      [innerHTML]=\"configs.subgrid_config.data_loading_text\"\r\n      class=\"subgrid-loading-text\"></td>\r\n  </tr>\r\n</ng-container>\r\n<ng-container *ngIf=\"!row_data.loading_children\">\r\n  <tr *ngFor=\"let child_data of row_data.children\">\r\n    <td *ngFor=\"let column of configs.subgrid_config.columns; index as i\">\r\n      <db-tree-cell\r\n        [configs]=\"configs\"\r\n        [column]=\"column\"\r\n        [index]=\"1\"\r\n        [row_data]=\"child_data\"\r\n        [expand_tracker]=\"expand_tracker\"\r\n        [cellclick]=\"cellclick\"\r\n      ></db-tree-cell>\r\n    </td>\r\n  </tr>\r\n  <tr *ngIf=\"configs.subgrid_config.show_summary_row\">\r\n    <td *ngFor=\"let column of configs.subgrid_config.columns\">\r\n      <div [innerHTML]=\"column.summary_renderer && column.summary_renderer(row_data.children)\"></div>\r\n    </td>\r\n  </tr>\r\n</ng-container>",
                styles: [".db-tree-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;word-break:keep-all;border:1px solid gray;color:#4b4b4b}tr.selected{background-color:#e2e7eb}tr span.parent_container{padding-left:45px}tr.child{background:#fff}tr.child td:nth-child(2){padding:.875rem 1.25rem .875rem 2.5rem!important}tr.parent{background:#fafbff}tr.subgrid-row{background:#fcfcfc}tr td{border:1px solid #cdd5dc;vertical-align:middle;position:relative;padding:.5rem;box-sizing:border-box}tr td.checkbox_column{text-align:center}tr td.expand-column{padding:.3rem}tr td.column-hide{display:none}tr td.clear-left-border{border-left:0!important}tr td.clear-right-border{border-right:0!important}td.subgrid-loading-text{text-align:center}"]
            }] }
];
/** @nocollapse */
SubgridBodyComponent.ctorParameters = () => [];
SubgridBodyComponent.propDecorators = {
    configs: [{ type: Input }],
    expand_tracker: [{ type: Input }],
    row_data: [{ type: Input }],
    cellclick: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/subgrid/subgrid.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class SubgridModule {
}
SubgridModule.decorators = [
    { type: NgModule, args: [{
                declarations: [SubgridComponent, SubgridHeadComponent, SubgridBodyComponent],
                imports: [
                    CommonModule,
                    TreeCellModule
                ],
                exports: [SubgridComponent]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-body/tree-body.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TreeBodyModule {
}
TreeBodyModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TreeBodyComponent, AddRowComponent, FilterRowComponent],
                imports: [
                    CommonModule,
                    TreeCellModule,
                    FormsModule,
                    SubgridModule
                ],
                exports: [TreeBodyComponent],
                providers: [AngularTreeGridService]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-head/tree-head.component.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TreeHeadComponent {
    /**
     * @param {?} angularTreeGridService
     */
    constructor(angularTreeGridService) {
        this.angularTreeGridService = angularTreeGridService;
    }
    /**
     * @return {?}
     */
    ngOnInit() { }
    /**
     * @return {?}
     */
    addRow() {
        this.internal_configs.show_add_row = true;
    }
    /**
     * @param {?} e
     * @return {?}
     */
    selectAll(e) {
        if (e.target.checked) {
            this.angularTreeGridService.selectAll(this.store.getDisplayData());
            this.rowselectall.emit(this.store.getDisplayData());
        }
        else {
            this.angularTreeGridService.deSelectAll(this.store.getDisplayData());
            this.rowdeselectall.emit(e);
        }
    }
}
TreeHeadComponent.decorators = [
    { type: Component, args: [{
                selector: '[db-tree-head]',
                template: "<ng-container *ngIf=\"configs\">\r\n  <tr [ngClass]=\"configs.css.header_class\">\r\n    <th *ngIf=\"configs.multi_select\" class=\"checkbox_column\">\r\n      <input type=\"checkbox\" (click)=\"selectAll($event)\" [checked]=\"this.internal_configs.all_selected\">\r\n    </th>\r\n    <th\r\n      *ngIf=\"(configs.actions.add || configs.actions.edit || configs.actions.delete) && (configs.action_column_position =='first')\"\r\n      class=\"action-column\" width=\"{{configs.action_column_width}}\">\r\n      <span class=\"icon-container\" (click)=\"addRow()\">\r\n        <i *ngIf=\"!internal_configs.show_add_row && configs.actions.add\" [ngClass]=\"configs.css.add_class\"\r\n          aria-hidden=\"true\" title=\"Add a row\"></i>\r\n      </span>\r\n      <span *ngIf=\"internal_configs.show_add_row || !configs.actions.add\">{{configs.action_column_text}}</span>\r\n    </th>\r\n    <th *ngFor=\"let column of columns\" [ngClass]=\"{'column-hide': column.hidden}\" [attr.width]=\"column.width\">\r\n      <div [innerHTML]=\"column.header_renderer ? column.header_renderer(column.header) : column.header\"></div>\r\n    </th>\r\n    <th *ngIf=\"(configs.show_parent_on_edit && internal_configs.show_parent_col) || internal_configs.show_add_row\">\r\n      Parent\r\n    </th>\r\n    <th\r\n      *ngIf=\"(configs.actions.add || configs.actions.edit || configs.actions.delete) && (configs.action_column_position =='last')\"\r\n      class=\"action-column\" width=\"{{configs.action_column_width}}\">\r\n      <span class=\"icon-container\" (click)=\"addRow()\">\r\n        <i *ngIf=\"!internal_configs.show_add_row && configs.actions.add\" [ngClass]=\"configs.css.add_class\"\r\n          aria-hidden=\"true\" title=\"Add a row\"></i>\r\n      </span>\r\n      <span *ngIf=\"internal_configs.show_add_row || !configs.actions.add\">{{configs.action_column_text}}</span>\r\n    </th>\r\n  </tr>\r\n</ng-container>",
                styles: [".db-tree-view{line-height:1.5em;border-collapse:collapse;border-spacing:0;display:table;max-width:100%;overflow:auto;word-break:normal;word-break:keep-all;border:1px solid gray;color:#4b4b4b}tr{background:#fff}tr th{font-size:1rem;font-weight:600;line-height:1.25;color:#181818;border:1px solid #cdd5dc;vertical-align:middle;position:relative;box-sizing:border-box}tr th div{padding:.5rem}tr th.column-hide{display:none}tr th.action-column span.icon-container{cursor:pointer}tr th i.plus{border:1px solid transparent}tr th i.plus:before{content:'';width:18px;height:1px;border-top:2px solid #222;display:block;position:absolute;margin-top:-15px;margin-left:6px}tr th i.plus:after{content:'';width:1px;height:18px;border-right:2px solid #222;display:block;position:absolute;margin-top:-23px;margin-left:14px}th.clear-left-border{border-left:0!important}th.clear-right-border{border-right:0!important}.column-hide{display:none}svg{width:25px;padding-right:3px}"]
            }] }
];
/** @nocollapse */
TreeHeadComponent.ctorParameters = () => [
    { type: AngularTreeGridService }
];
TreeHeadComponent.propDecorators = {
    store: [{ type: Input }],
    configs: [{ type: Input }],
    expand_tracker: [{ type: Input }],
    edit_tracker: [{ type: Input }],
    internal_configs: [{ type: Input }],
    columns: [{ type: Input }],
    rowselectall: [{ type: Input }],
    rowdeselectall: [{ type: Input }]
};

/**
 * @fileoverview added by tsickle
 * Generated from: lib/modules/tree-head/tree-head.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class TreeHeadModule {
}
TreeHeadModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TreeHeadComponent],
                imports: [
                    CommonModule
                ],
                exports: [TreeHeadComponent],
                providers: [AngularTreeGridService]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: lib/angular-tree-grid.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class AngularTreeGridModule {
}
AngularTreeGridModule.decorators = [
    { type: NgModule, args: [{
                declarations: [AngularTreeGridComponent],
                imports: [
                    CommonModule,
                    TreeBodyModule,
                    TreeHeadModule
                ],
                exports: [AngularTreeGridComponent],
                providers: [AngularTreeGridService]
            },] }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: angular-tree-grid.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingRequire,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { AngularTreeGridService, AngularTreeGridComponent, AngularTreeGridModule, DefaultEditor, SubgridBodyComponent as ɵo, SubgridHeadComponent as ɵn, SubgridComponent as ɵm, SubgridModule as ɵl, AddRowComponent as ɵc, FilterRowComponent as ɵd, TreeBodyComponent as ɵb, TreeBodyModule as ɵa, TreeCellActionsComponent as ɵi, CustomCellEditorComponent as ɵj, TreeCellEditorComponent as ɵk, CustomCellViewComponent as ɵh, TreeCellViewComponent as ɵg, TreeCellComponent as ɵf, TreeCellModule as ɵe, TreeHeadComponent as ɵq, TreeHeadModule as ɵp };

//# sourceMappingURL=angular-tree-grid.js.map